@@ -7,7 +7,7 @@ use Test::More;
 sub import {
     my $class = shift;
     my $caller = caller;
-    eval "package $caller; use Test::More; 1" || die $@;
+    eval "package $caller; use Test::More; 1" || die $@;  ## no critic
     after_runtime { done_testing() };
 }
 
